      SUBROUTINE reacir

C**** *reacir* - READs velocity and thermohaline fields

C     c. heinze            mpi hamburg      88/12/01.

C     purpose.
C     --------
C          *reacir* READs velocity and thermohaline fields
C     provided by uwe mikolajewicz's ogcm version.


C**   interface.
C     ----------
C          *call* *reacir*

C     method.
C     -------
C          -.

C     externals.
C     ----------
C          none.

C     reference.
C     ----------
C          -.

C*     variable    type    purpose.
C      --------    ----    --------

C      *      *    REAL    xxx

C     -----------------------------------------------------------------
      INCLUDE 'parameter.include'
      INCLUDE 'common.horvel'
      INCLUDE 'common.wathic'
      INCLUDE 'common.chemis'
      INCLUDE 'common.biocon'
      INCLUDE 'common.topogr'
      INCLUDE 'common.production'
      INCLUDE 'common.thermo'
      INCLUDE 'common.ctrac'
      INCLUDE 'common.divers'
      INCLUDE 'common.caco3c'
      INCLUDE 'equivalence.include'
      CHARACTER c80*80
      logical test,succes(9,ke),suSTOP,oldmod
      DIMENSION iddr(512),oddr(512),zprel(6),rmintu(kep),
     .   rmintw(kep),rmdzw(ke),rlali(je),iconum(9)
      DIMENSION skipar(ie,je)

      DO 1000 m=1,9
      DO 1000 k=1,ke
        succes(m,k)=.false.
 1000 CONTINUE

C     -----------------------------------------------------------------
C*         0. code numbers of arrays to be READ from unit 38
C             ---- ------- -- ------ -- -- ---- ---- ---- --
C    channel 1       -3 zonal velocity component
C            2       -4 meridional velocity component
C            3       -7 vertical velocity component
C            4       -2 pot. temp.
C            5       -5 salinity
C            6      -69 convective adjustment
C            7      -98 depth at scalar points
C            8      -99 depth at vector points
C            9      -13 ice thickness
      iconum(1)=-3
      iconum(2)=-4
      iconum(3)=-7
      iconum(4)=-2
      iconum(5)=-5
      iconum(6)=-69
      iconum(7)=-98
      iconum(8)=-99
      iconum(9)=-13
      oldmod=.true.
      DO 1100 i=1,ie
      DO 1100 j=1,je
        deptp(i,j)=88.88
        deptu(i,j)=88.88
        thicic(i,j)=88.88
 1100 CONTINUE

C     -----------------------------------------------------------------
C*         1. READ main headers
C             ---- ---- -------

      OPEN(42,file="VELO.ASC")
        READ(42,*) iddr
        READ(42,*) oddr
        READ(42,*) zprel
        READ(42,*) skipar
        READ(42,*) u
        READ(42,*) v
        READ(42,*) w
        READ(42,*) tem
        READ(42,*) sal
        READ(42,*) convad
        READ(42,*) deptp
        READ(42,*) deptu
        READ(42,*) thicic
        CLOSE(42)

C     -----------------------------------------------------------------
C*         2. set essential PARAMETERs from main header info
C             --- --------- ---------- ---- ---- ------ ----

C*         2.1 date and year of DATA
      idadat=iddr(11)
      idatim=iddr(12)
      print*,'***cir date time ',idadat,idatim

C*         2.2 number of points on latitude line
      iecir=iddr(19)

C*         2.3 number of latitude lines
      jecir=iddr(20)

C*         2.4 number of layers
      kecir=iddr(21)
      print*,'***cir ie je ke ',iecir,jecir,kecir

C*         2.6 set depth levels in m
      rmintw(1)=0.
      DO 1 k=1,kep
        rmintu(k)=oddr(9+k)
        IF(k.GT.1)rmintw(k)=rmintu(k-1)+(rmintu(k)-rmintu(k-1))/2.
    1 CONTINUE

C*         2.7 set layer thicknesses in m
      DO 2 k=1,ke
        rmdzw(k)=rmintw(k+1)-rmintw(k)
    2 CONTINUE

C*         2.8 zonal and merdional grid step in degrees
      zongri=oddr(50)
      rmegri=oddr(51)
      print*,'***cir zongri rmegri ',zongri,rmegri

C*         2.8 latitudes of lat. lines (degrees)
      DO 3 j=1,je
        rlali(j)=oddr(51+j)
    3 CONTINUE


C     -----------------------------------------------------------------
C*         5. calculate geometric variables
C             --------- --------- ---------

C*         5.1 INTEGER value of w and u point depth levels in cm
      DO 8 k=1,kep
        intw(k)=nINT(rmintw(k)*100.)
        intu(k)=nINT(rmintu(k)*100.)
    8 CONTINUE
C        print*,'***uwe new intw ',intw
C        print*,'***uwe new intu ',intu

C*         5.x layer thickness (cm)
      DO 501 k=1,ke
        dzw(k)=real(intw(k+1)-intw(k))
C       print*,'***uwe dzw(',k,')=',dzw(k)
  501 CONTINUE

C*         5.1 wet layer thickness at individual vector/scalar point
      DO 9 k=1,ke
      DO 9 j=1,je
      DO 9 i=1,ie
        ddu(i,j,k)=real(intw(k+1))-real(intw(k))
        IF(deptu(i,j).le.real(intu(k)))then
          ddu(i,j,k)=0.
        ELSE IF(deptu(i,j).LT.real(intw(k+1)))then
          ddu(i,j,k)=deptu(i,j)-real(intw(k))
        ELSE IF(deptu(i,j).le.real(intu(k+1)))then
          ddu(i,j,k)=deptu(i,j)-real(intw(k))
        ENDIF
        ddz(i,j,k)=real(intw(k+1))-real(intw(k))
        IF(deptp(i,j).le.real(intu(k)))then
          ddz(i,j,k)=0.
        ELSE IF(deptp(i,j).LT.real(intw(k+1)))then
          ddz(i,j,k)=deptp(i,j)-real(intw(k))
        ELSE IF(deptp(i,j).le.real(intu(k+1)))then
          ddz(i,j,k)=deptp(i,j)-real(intw(k))
        ENDIF
    9 CONTINUE

      WRITE(39,'(''***uwe old units ddz uwe n-atl'')')
      DO 3010 j=1,35
 3010   WRITE(39,'(11(1x,e10.4))')(ddz(4,j,k),k=1,11)

      WRITE(39,'(''***uwe old units ddu uwe n-atl'')')
      DO 3011 j=1,35
 3011   WRITE(39,'(11(1x,e10.4))')(ddu(4,j,k),k=1,11)
      test=.false.
      IF(test) STOP 'reacir test'
      RETURN
      END
