c   VARIABLE DECLARATION STRATEGY

c   GCM
c      3-D arrays of alk, tco2, t, s, z

c   sed_main(alk,tco2,t,s,water_z,ddz,dimensions,
c            rain rates, delC rain,
c            timestep,n_quit

c       updates values in alk, tco2, delC, diagnostics
c       maps 3-D bottom values into 2-D arrays for subroutines
c            uses local arrays map_x(n):integer, etc y, z
c
c            entry setup:
c               foreach x,y,z
c                  if (bottom_water) then
c                     map_x(n) = x; etc y, z
c                     temp_2D(n) = temp_3D(map_x(n),map_y(n),map_z(n))
c                        etc sal, water_z, delz
c                     n = n + 1
c                  endif
c               end
c               determine k1, k2 (n)
c               initialize porewater chemistry
c               calculate diffusion coefficients
c            end
c
c            entry step:
c               foreach n
c                  alk_2D(n) = alk_3D(map_x(n), map_y(n), map_z(n))
c                  etc, tco2 
c               end
c               do step (update alk_2D(n), etc tco2, delC)
c               foreach n
c                  alk_3D(map_x(n),map_y(n),map_z(n))
c                    = alk_2D(n)
c                  etc tco2, delC
c               end
c            end
c                
c               
c       arguments:       alk_3D, tco2_3D, del13C_3D, del14C_3D
c                        temp_3D, sal_3D
c                        topography_2D, delz_3D
c                        external array dimensions
c                        rain rates, delC rains
c                        timestep
c
c       local variables: map_x, map_y, map_z, n_map_max
c                        alk_2D, tco2_2D, del13C_2D, del14C_2D
c                        temp_2D,sal_2D
c                        k1_2D, k2_2D
c                        pw chemistry
c                        solid profiles
c                        physical layout (z, delz, pore, form, etc)
c                        scaled diffusion coefficients, solid + solute
c                        a, b matrix working space
c                        resp_c, cal_c working space



      SUBROUTINE init_sed

      INCLUDE 'parameter.include'
      INCLUDE 'parameter.sediment.include'

      INCLUDE 'common.ctrac'
c       the water column arrays, ca
      INCLUDE 'common.topogr'
c       deptp (i,j), depth of water column
      INCLUDE 'common.production'
c       prorca,prcaca,pr13pr,pr14pr
      INCLUDE 'common.chemis'
c       sdfxoc and sdfxca
      INCLUDE 'common.wathic'
c       ddz
      INCLUDE 'common.divers'
c       intw
      INCLUDE 'common.thermo'
c       tem and sal

      INCLUDE 'common.sediment'
      INCLUDE 'common.seddiag'
c      INCLUDE 'common.seddebug'

      LOGICAL i_cheat

        i_parallel = 0
        DO 20 i = 1, ie
          DO 20 j = jl1, jle
            DO 20 k = 1, ke
c             select for bottom water boxes
               IF(
     *              ( rwat(i,j) .NE. 0. ) .AND.
     *              ( ddz(i,j,k) .GT. 0. )
     *           ) THEN
                  IF( k .LT. ke ) THEN
                     IF( ddz(i,j,k+1) .LE. 0. ) THEN
                        i_parallel = i_parallel + 1
                        map_x(i_parallel) = i
                        map_y(i_parallel) = j
                        map_z(i_parallel) = k
                        temp_p(i_parallel) = tem(i,j,k)
                        sal_p(i_parallel) = sal(i,j,k)
                        water_z_p(i_parallel)
     $                       = deptp(i,j) / 100.
                     ENDIF
                  ELSE
                     i_parallel = i_parallel + 1
                     map_x(i_parallel) = i
                     map_y(i_parallel) = j
                     map_z(i_parallel) = k
                     temp_p(i_parallel) = tem(i,j,k)
                     sal_p(i_parallel) = sal(i,j,k)
                     water_z_p(i_parallel)
     $                    = deptp(i,j) / 100.
                  ENDIF
               ENDIF
 20     CONTINUE

c        write(7,*) kmax,i_parallel,map_x,map_y,map_z,
c     *       tem,sal,deptp,ddz
c        pause

c       check -- do we got em all?
c        DO 21 i = 1, ie
c          DO 21 j = jl1, jle
c            DO 21 k = 1, ke
c               IF( ddz(i,j,1) .NE. 0.


        CALL init_stuff(kmax,
     *              z,delz,pore,form,
     *              o2,carb,zrct,
     *              orggg,orgml,calgg,calml,
     *              dopls,domin,dcpls,dcmin,dbpls,dbmin,
     *              i_parallel,ip_sedmain_max,nz_sedmain_max)

        CALL set_nshore(near_shore, near_off_shore)

        CALL calc_k(temp_p,sal_p,water_z_p,k1,k2,kb,csat,
     *               i_parallel)

        i_cheat = .FALSE.

c        IF( i_cheat ) THEN
c           OPEN(UNIT=53,file='SED.RESTART',status='unknown',
c     .         access='sequential',form='unformatted')
c           READ(53) orggg,calgg,o2,carb,zrct
c        ENDIF

      CALL set_pore(calgg,z,pore,
     *              kmax,i_parallel,ip_sedmain_max,nz_sedmain_max)
 

      CALL sldcon(orgml,orggg,12.,pore,kmax,
     .            i_parallel,ip_sedmain_max,nz_sedmain_max)
      CALL sldcon(calml,calgg,100.,pore,kmax,
     .            i_parallel,ip_sedmain_max,nz_sedmain_max)

      dissc = 1.1574e-5 
      dissn = 4.5

c     calculate mass of mixed layer
c       units of g/cm2

      CALL get_sed_ml_mass(delz,pore,
     *     sed_ml_mass,
     *     nz_sedmain_max,i_parallel,ip_sedmain_max,kmax)

      DO 30, k = 1, i_bur_rec_max
         depth_age(k) = 4000. * (k-1)
   30 CONTINUE
c     Note: initial buried calcite setup in sed_ss (since it
c     needs to know the steady state caco3 concentration)

      RETURN
      END

      SUBROUTINE sediment(n_control,nyear,sum_burial)

      INCLUDE 'parameter.include'
      INCLUDE 'parameter.sediment.include'

      INCLUDE 'common.ctrac'
c       the water column arrays, ca
      INCLUDE 'common.topogr'
c       deptp (i,j), depth of water column
      INCLUDE 'common.production'
c       prorca, prcaca, pr13pr, pr14pr,sdfxor,sdfxca
      INCLUDE 'common.chemis'
c       sdfxoc and sdfxca
      INCLUDE 'common.wathic'
c       ddz
      INCLUDE 'common.divers'
c       intw
      INCLUDE 'common.biocon'
c       rno3, dphi
      INCLUDE 'equivalence.include'

      INCLUDE 'common.sediment'
      INCLUDE 'common.seddiag'
c      include 'common.seddebug'

c   results from sediment
      REAL ttrorg(ip_sedmain_max)
      REAL ttrtc(ip_sedmain_max)
      REAL ttral(ip_sedmain_max)
      REAL difal(ip_sedmain_max)
      REAL diftc(ip_sedmain_max)
c      (in common)
c      REAL ttrcal(ip_sedmain_max)
c      REAL c_advect(ip_sedmain_max)

c   internal variables to sediment
      REAL alk_p(ip_sedmain_max),tco2_p(ip_sedmain_max)
      REAL o2_bw_p(ip_sedmain_max)
      REAL rain_org_p(ip_sedmain_max),rain_cal_p(ip_sedmain_max)
      REAL rain_clay_p(ip_sedmain_max)
      REAL co2_p(ip_sedmain_max),hco3_p(ip_sedmain_max)
      REAL co3_p(ip_sedmain_max)
      REAL resp_c(ip_sedmain_max,nz_sedmain_max,3)
      REAL cal_c(ip_sedmain_max,nz_sedmain_max)
      REAL fract_rediss(ip_sedmain_max)

      SAVE fract_rediss

      LOGICAL i_cheat

        DO 30 ip = 1, i_parallel
          alk_p(ip) = alkali(map_x(ip),map_y(ip),map_z(ip))
          tco2_p(ip) = sco212(map_x(ip),map_y(ip),map_z(ip))
c           prevent anoxic sediment case
          o2_bw_p(ip) = MAX(oxygen(map_x(ip),map_y(ip),map_z(ip)),
     *                      10.E-6)
          rain_org_p(ip) = sdfxoc(map_x(ip),map_y(ip))
     *                     * ddz(map_x(ip),map_y(ip),1)
     *                     * prorca(map_x(ip),map_y(ip))
     *                     * 1.E-3
          rain_cal_p(ip) = sdfxca(map_x(ip),map_y(ip))
     *                     * ddz(map_x(ip),map_y(ip),1)
     *                     * prcaca(map_x(ip),map_y(ip))
     *                     * 1.E-3
          rain_clay_p(ip) = 18.E-5
          IF (near_shore(map_x(ip),map_y(ip)) .EQ. 1) THEN 
             rain_clay_p(ip)
     *            = rain_clay_p(ip) * 100.
          ENDIF
          IF (near_off_shore(map_x(ip),map_y(ip)) .EQ. 1) THEN
             rain_clay_p(ip)
     *            = rain_clay_p(ip) * 10.
          ENDIF
 30     CONTINUE

           CALL calc_buff(alk_p,tco2_p,sal_p,k1,k2,kb,
     .          co2_p,hco3_p,co3_p,
     .          i_parallel)
c     sets up only the bottom water values; run every time

c!!!!! adjust the bottom water co3 chemistry to simulate the glacial
c     state according to Emerson and Archer 92

c           DO 1001 ip=1, i_parallel
c              i = map_x(ip)
c              j = map_y(ip)
c              lat = 88.75 - (j-jl1)*2.5
c              longt = MOD( (i-1)*5. - (j-jl1)*2.5 + 360., 360.)
c              csat_old = csat(ip)
c              IF(longt .GT. 30 .AND. longt .LT. 130) THEN
c                 csat(ip) = csat(ip) - 10.E-6
c              ELSEIF(longt .GE. 130 .AND. longt .LT. 300) THEN
c                 csat(ip) = csat(ip) - 7.E-6
c              ELSE
c                 csat(ip) = csat(ip) + 11.E-6
c              ENDIF
c              write(12,*) ip, longt, csat(ip), csat_old
c 1001      CONTINUE

c           WRITE(6,*) "adjusting csat for glacial simulation"

         WRITE(6,*) "deep np co3 ", co3_p(1620)
         WRITE(6,*) "deep np alky ", alkali(48,21,11)



        CALL setup_pw(co2_p,hco3_p,co3_p,o2_bw_p,
     .          carb,o2,csat,
     .          kmax,i_parallel,ip_sedmain_max,nz_sedmain_max)
        

        CALL estimate_rc(rain_org_p,rc,i_parallel)
           
        IF( n_control .EQ. -1) THEN
c     then initialize without setting calcite concentration

           CALL bury(0,z,delz,pore,kmax,
     *                calgg,orggg,sed_ml_mass,
     *                rain_cal_p,ttrcal,c_advect,
     *                rain_clay_p,
     *                nyear,
     *                buried_mass,buried_calfrac,depth_age,
     *                i_parallel,
     *                ip_sedmain_max,nz_sedmain_max,i_bur_rec_max)

        ELSEIF( n_control .EQ. 1) THEN
c     then find steady state calcite concentration

c           OPEN(UNIT=10,FILE='calgg.save')
c           READ(10,*) calgg,orggg,ttrcal,c_advect

           CALL sed_ss(z,delz,form,pore,kmax,
     *          o2,zrct,carb,	
     *          orgml,orggg,calml,calgg,	
     *          rain_cal_p,rain_org_p,rain_clay_p,	
     *          r13or,r14or,r13ca,r14ca,	
     *          rc,dissc,dissn,csat,k1,k2,	
     *          dopls,domin,dcpls,dcmin,dbpls,dbmin,
     *          resp_c,cal_c,
     *          ttrorg,ttrcal,
     *          ttrtc,ttral,
     *          diftc,difal,
     *          c_advect,
     *          buried_mass,buried_calfrac,n_buried_depths,
     .          i_parallel,ip_sedmain_max,nz_sedmain_max,
     *          i_bur_rec_max,
     *          n_control)	
          
c   this takes the place of what sed_ss is supposed to do
c      DO 1000 ip = 1, i_parallel
c         buried_mass(1,ip) = 500.
c         buried_calfrac(1,ip) = calgg(kmax,ip)
c         DO 1000 k = 2, i_bur_rec_max
c            buried_mass(k,ip) = 0.
c            buried_calfrac(k,ip) = calgg(kmax,ip)
c 1000 CONTINUE

           DO 34 i = 1, ie
              DO 34 j = 1, je
                 dissfrc(i,j) = 0.
   34      CONTINUE

           DO 35 ip = 1, i_parallel
              IF( rain_cal_p(ip) .GT. 1.E-8 ) THEN
                 fract_rediss(ip) = ttrcal(ip) / rain_cal_p(ip)
              ELSE
                 fract_rediss(ip) = 1.
              ENDIF
              dissfrc(map_x(ip),map_y(ip))
     *             = fract_rediss(ip)
   35      CONTINUE


           CALL bury(0,z,delz,pore,kmax,
     *                calgg,orggg,sed_ml_mass,
     *                rain_cal_p,ttrcal,c_advect,
     *                rain_clay_p,
     *                nyear,
     *                buried_mass,buried_calfrac,depth_age,
     *                i_parallel,
     *                ip_sedmain_max,nz_sedmain_max,i_bur_rec_max)

c           WRITE(6,*) "check with 1 kyr of drift"
c           DO 435 j = 1, 1000

c              CALL bury(2,z,delz,pore,kmax,
c     *             calgg,orggg,sed_ml_mass,
c     *             rain_cal_p,ttrcal,c_advect,
c     *             rain_clay_p,
c     *             nyear,
c     *             buried_mass,buried_calfrac,depth_age,
c     *             i_parallel,
c     *             ip_sedmain_max,nz_sedmain_max,i_bur_rec_max)

c 435       CONTINUE
c           WRITE(6,*) "done with drift"
c           CALL pools

        ELSEIF ( n_control .EQ. 2 ) THEN
c     step ahead time-dependent calcite concentration

           CALL sed_const_cal(z,delz,form,pore,kmax,
     *          o2,zrct,carb,	
     *          orgml,orggg,calml,calgg,	
     *          rain_cal_p,rain_org_p,rain_clay_p,	
     *          r13or,r14or,r13ca,r14ca,	
     *          rc,dissc,dissn,csat,k1,k2,
     *          dopls,domin,dcpls,dcmin,dbpls,dbmin,
     *          resp_c,cal_c,
     *          ttrorg,ttrcal,
     *          ttrtc,ttral,
     *          diftc,difal,
     *          c_advect,
     .          i_parallel,ip_sedmain_max,nz_sedmain_max,
     *          n_control)

           DO 234 i = 1, ie
              DO 234 j = 1, je
                 dissfrc(i,j) = 0.
  234         CONTINUE

           DO 235 ip = 1, i_parallel
              IF( rain_cal_p(ip) .GT. 1.E-8 ) THEN
                 fract_rediss(ip) = ttrcal(ip) / rain_cal_p(ip)
              ELSE
                 fract_rediss(ip) = 1.
              ENDIF
              dissfrc(map_x(ip),map_y(ip))
     *             = fract_rediss(ip)
  235      CONTINUE

           CALL bury(2,z,delz,pore,kmax,
     *          calgg,orggg,sed_ml_mass,
     *          rain_cal_p,ttrcal,c_advect,
     *          rain_clay_p,
     *          nyear,
     *          buried_mass,buried_calfrac,depth_age,
     *          i_parallel,
     *          ip_sedmain_max,nz_sedmain_max,i_bur_rec_max)

        ELSEIF( n_control .EQ. 3) THEN
c       maintain constant calcite concentration (update diss but don't bury)
           CALL sed_const_cal(z,delz,form,pore,kmax,
     *          o2,zrct,carb,	
     *          orgml,orggg,calml,calgg,	
     *          rain_cal_p,rain_org_p,rain_clay_p,	
     *          r13or,r14or,r13ca,r14ca,	
     *          rc,dissc,dissn,csat,k1,k2,	
     *          dopls,domin,dcpls,dcmin,dbpls,dbmin,
     *          resp_c,cal_c,
     *          ttrorg,ttrcal,
     *          ttrtc,ttral,
     *          diftc,difal,
     *          c_advect,
     .          i_parallel,ip_sedmain_max,nz_sedmain_max,
     *          n_control)	

           DO 134 i = 1, ie
              DO 134 j = 1, je
                 dissfrc(i,j) = 0.
  134         CONTINUE

           DO 135 ip = 1, i_parallel
              IF( rain_cal_p(ip) .GT. 1.E-8 ) THEN
                 fract_rediss(ip) = ttrcal(ip) / rain_cal_p(ip)
              ELSE
                 fract_rediss(ip) = 1.
              ENDIF
              dissfrc(map_x(ip),map_y(ip))
     *             = fract_rediss(ip)
  135      CONTINUE

        ELSEIF( n_control .EQ. 4) THEN
           
           DO 140 ip = 1, i_parallel
              fract_rediss(ip) = 1.0
              dissfrc(map_x(ip),map_y(ip)) = 1.0
  140      CONTINUE
           
        ELSEIF( n_control .EQ. 5) THEN
c          use old reaction rates but update bury
           
           DO 154 i = 1, ie
              DO 154 j = 1, je
                 dissfrc(i,j) = 0.
  154         CONTINUE

           DO 150 ip = 1, i_parallel
              IF( rain_cal_p(ip) .GT. 1.E-8 ) THEN
                 fract_rediss(ip) = ttrcal(ip) / rain_cal_p(ip)
              ELSE
                 fract_rediss(ip) = 1.
              ENDIF
              dissfrc(map_x(ip),map_y(ip)) = fract_rediss(ip)
  150      CONTINUE

           CALL bury(2,z,delz,pore,kmax,
     *          calgg,orggg,sed_ml_mass,
     *          rain_cal_p,ttrcal,c_advect,
     *          rain_clay_p,
     *          nyear,
     *          buried_mass,buried_calfrac,depth_age,
     *          i_parallel,
     *          ip_sedmain_max,nz_sedmain_max,i_bur_rec_max)

        ELSEIF ( n_control .EQ. 6 ) THEN
c          update dissolution rates and step forward bury many years, for 
c          debugging

           CALL sed_const_cal(z,delz,form,pore,kmax,
     *          o2,zrct,carb,	
     *          orgml,orggg,calml,calgg,	
     *          rain_cal_p,rain_org_p,rain_clay_p,	
     *          r13or,r14or,r13ca,r14ca,	
     *          rc,dissc,dissn,csat,k1,k2,
     *          dopls,domin,dcpls,dcmin,dbpls,dbmin,
     *          resp_c,cal_c,
     *          ttrorg,ttrcal,
     *          ttrtc,ttral,
     *          diftc,difal,
     *          c_advect,
     .          i_parallel,ip_sedmain_max,nz_sedmain_max,
     *          n_control)

           DO 634 i = 1, ie
              DO 634 j = 1, je
                 dissfrc(i,j) = 0.
  634         CONTINUE

           DO 635 ip = 1, i_parallel
              IF( rain_cal_p(ip) .GT. 1.E-8 ) THEN
                 fract_rediss(ip) = ttrcal(ip) / rain_cal_p(ip)
              ELSE
                 fract_rediss(ip) = 1.
              ENDIF
              dissfrc(map_x(ip),map_y(ip))
     *             = fract_rediss(ip)
  635      CONTINUE

           do i_year = 1, 1000
              CALL bury(2,z,delz,pore,kmax,
     *             calgg,orggg,sed_ml_mass,
     *             rain_cal_p,ttrcal,c_advect,
     *             rain_clay_p,
     *             nyear,
     *             buried_mass,buried_calfrac,depth_age,
     *             i_parallel,
     *             ip_sedmain_max,nz_sedmain_max,i_bur_rec_max)
           enddo
           call pools

       ENDIF
        
       expb = 3.0
       call pore_2_form(pore,form,kmax,expb,
     .        i_parallel,ip_sedmain_max,nz_sedmain_max)
       CALL sldcon(calml,calgg,100.,pore,kmax,
     .            i_parallel,ip_sedmain_max,nz_sedmain_max)
       CALL sldcon(orgml,orggg,12.,pore,kmax,
     .            i_parallel,ip_sedmain_max,nz_sedmain_max)
       CALL calc_do2(difo2,
     *      form,pore,delz,kmax,
     *      dopls,domin,i_parallel,ip_sedmain_max,nz_sedmain_max)
       CALL calc_dc(difc,form,pore,delz,kmax,
     .            dcpls,dcmin,
     .            i_parallel,ip_sedmain_max,nz_sedmain_max)
       CALL calc_db(db,
     .             pore,zsed,delz,kmax,
     .             dbpls,dbmin,
     .             i_parallel,ip_sedmain_max,nz_sedmain_max)


c       call pools

        gim = 0.006 * dphi

        sum_burial = 0.
        sum_diss = 0.
        cal_avg = 0.

        DO 40 ip = 1, i_parallel
           sco212(map_x(ip),map_y(ip),map_z(ip))
     .           = sco212(map_x(ip),map_y(ip),map_z(ip))
     .           + sdfxoc(map_x(ip),map_y(ip))
     *             * ddz(map_x(ip),map_y(ip),1)
     *             / ddz(map_x(ip),map_y(ip),map_z(ip))
     *             * prorca(map_x(ip),map_y(ip))
     *           + fract_rediss(ip)
     .             * sdfxca(map_x(ip),map_y(ip))
     *             * ddz(map_x(ip),map_y(ip),1)
     *             / ddz(map_x(ip),map_y(ip),map_z(ip))
     *             * prcaca(map_x(ip),map_y(ip))
c           sco212(map_x(ip),map_y(ip),1)
c     .           = sco212(map_x(ip),map_y(ip),1)
c     *           + ( 1 - fract_rediss(ip) )
c     .             * sdfxca(map_x(ip),map_y(ip))
c     *             * prcaca(map_x(ip),map_y(ip))
           sco213(map_x(ip),map_y(ip),map_z(ip))
     .           = sco213(map_x(ip),map_y(ip),map_z(ip))
     .           + sdfxoc(map_x(ip),map_y(ip))
     *             * ddz(map_x(ip),map_y(ip),1)
     *             / ddz(map_x(ip),map_y(ip),map_z(ip))
     *             * prorca(map_x(ip),map_y(ip))
     *             * pr13pr(map_x(ip),map_y(ip))
     *           + fract_rediss(ip)
     .             * sdfxca(map_x(ip),map_y(ip))
     *             * ddz(map_x(ip),map_y(ip),1)
     *             / ddz(map_x(ip),map_y(ip),map_z(ip))
     *             * prcaca(map_x(ip),map_y(ip))
     *             * pr13pr(map_x(ip),map_y(ip))
c           sco213(map_x(ip),map_y(ip),1)
c     .           = sco213(map_x(ip),map_y(ip),1)
c     *           + ( 1 - fract_rediss(ip) )
c     .             * sdfxca(map_x(ip),map_y(ip))
c     *             * prcaca(map_x(ip),map_y(ip))
c     *             * pr13pr(map_x(ip),map_y(ip))
           sco214(map_x(ip),map_y(ip),map_z(ip))
     .           = sco214(map_x(ip),map_y(ip),map_z(ip))
     .           + sdfxoc(map_x(ip),map_y(ip))
     *             * ddz(map_x(ip),map_y(ip),1)
     *             / ddz(map_x(ip),map_y(ip),map_z(ip))
     *             * prorca(map_x(ip),map_y(ip))
     *             * pr14pr(map_x(ip),map_y(ip))
     *           + fract_rediss(ip)
     .             * sdfxca(map_x(ip),map_y(ip))
     *             * ddz(map_x(ip),map_y(ip),1)
     *             / ddz(map_x(ip),map_y(ip),map_z(ip))
     *             * prcaca(map_x(ip),map_y(ip))
     *             * pr14pr(map_x(ip),map_y(ip))
c           sco214(map_x(ip),map_y(ip),1)
c     .           = sco214(map_x(ip),map_y(ip),1)
c     *           + ( 1 - fract_rediss(ip) )
c     .             * sdfxca(map_x(ip),map_y(ip))
c     *             * prcaca(map_x(ip),map_y(ip))
c     *             * pr14pr(map_x(ip),map_y(ip))
           alkali(map_x(ip),map_y(ip),map_z(ip))
     .           = alkali(map_x(ip),map_y(ip),map_z(ip))
     .           - sdfxoc(map_x(ip),map_y(ip))
     *             * ddz(map_x(ip),map_y(ip),1)
     *             / ddz(map_x(ip),map_y(ip),map_z(ip))
     *             * prorca(map_x(ip),map_y(ip))
     *             * rno3
     *           + fract_rediss(ip)
     .             * sdfxca(map_x(ip),map_y(ip))
     *             * ddz(map_x(ip),map_y(ip),1)
     *             / ddz(map_x(ip),map_y(ip),map_z(ip))
     *             * prcaca(map_x(ip),map_y(ip))
     *             * 2.0
c           alkali(map_x(ip),map_y(ip),1)
c     .           = alkali(map_x(ip),map_y(ip),1)
c     *           + ( 1 - fract_rediss(ip) )
c     .             * sdfxca(map_x(ip),map_y(ip))
c     *             * prcaca(map_x(ip),map_y(ip))
c     *             * 2.0
           phosph(map_x(ip),map_y(ip),map_z(ip))
     .           = phosph(map_x(ip),map_y(ip),map_z(ip))
     .           + sdfxoc(map_x(ip),map_y(ip))
     *             * ddz(map_x(ip),map_y(ip),1)
     *             / ddz(map_x(ip),map_y(ip),map_z(ip))
     *             * prorca(map_x(ip),map_y(ip))

c     check this!  need o2ut, negative?

           oxygen(map_x(ip),map_y(ip),map_z(ip))
     .           = oxygen(map_x(ip),map_y(ip),map_z(ip))
     .           + sdfxoc(map_x(ip),map_y(ip))
     *             * ddz(map_x(ip),map_y(ip),1)
     *             / ddz(map_x(ip),map_y(ip),map_z(ip))
     *             * prorca(map_x(ip),map_y(ip))

c           IF( fract_rediss(ip) .GT. 4) THEN
c              fract_rediss(ip) = 1
c           ENDIF

           sum_burial = sum_burial
     *          + gim * dzdl(map_x(ip),map_y(ip),1)
     *          * prcaca(map_x(ip),map_y(ip))
     *          * sdfxca(map_x(ip),map_y(ip))
     *          * ( 1 - fract_rediss(ip) )

           sum_diss = sum_diss
     *          + gim * dzdl(map_x(ip),map_y(ip),1)
     *          * prcaca(map_x(ip),map_y(ip))
     *          * sdfxca(map_x(ip),map_y(ip))
     *          * ( fract_rediss(ip) )

           cal_avg = cal_avg + calgg(kmax,ip)

 40     CONTINUE

        sum_burial = sum_burial * 1.E-15
        sum_diss = sum_diss * 1.E-15
        cal_avg = cal_avg / i_parallel * 100.

        

        WRITE(6,*) 'burial flux = ',sum_burial,'  GT C'
        WRITE(6,*) 'dissol flux = ',sum_diss,'  GT C'
        WRITE(6,*) 'average % CaCO3 = ', cal_avg

      RETURN
      END
